{% extends "registration/base.html" %}
{% load bulma_tags i18n %}

{% block content %}

  {% if form.errors %}
    <p>{% trans "Your username and password didn't match. Please try again." %}</p>
  {% endif %}

  <form method="post" action="{% url 'login' %}">
    {% csrf_token %}
    {{ form|bulma }}
    <div class="field">
      <button type="submit" class="button is-primary">{% trans 'Log in' %}</button>
    </div>
    <input type="hidden" name="next" value="{{ next }}"/>
  </form>

{% endblock %}