{% extends "registration/base.html" %}
{% load i18n static bulma_tags %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1 class="title">{{ title }}</h1>{% endblock %}
{% block content %}
  <p class="content">{% trans "Forgotten your password? Enter your email address below, and we'll email instructions for setting a new one." %}</p>
  <form method="post">{% csrf_token %}
    {{ form|bulma }}
    <button type="submit" class="button is-primary">{% trans 'Reset my password' %}</button>
  </form>
{% endblock %}