{% extends "registration/base.html" %}
{% load i18n %}

{% block content %}
  <p class="content">{% trans "Thanks for spending some quality time with the Web site today." %}</p>
  <p><a class="button is-success" href="{% url 'login' %}">{% trans 'Log in again' %}</a></p>
{% endblock %}