// 1. Import the initial variables
@import "./node_modules/bulma/sass/utilities/initial-variables"

// 2. Set your own initial variables

// 3. Import the rest of Bulma
@import "./node_modules/bulma/bulma"

// 4. Import your stuff here