{% extends "registration/base.html" %}
{% load i18n static bulma_tags %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1 class="title">{{ title }}</h1>{% endblock %}
{% block content %}

  {% if validlink %}
    <p class="content">{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
    <form method="post">{% csrf_token %}
      {{ form|bulma }}
      <button type="submit" class="button is-primary">{% trans 'Change my password' %}</button>
    </form>
  {% else %}
    <p class="content">{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>
  {% endif %}

{% endblock %}